bling.util


as-strclj/s

(as-str x)
source

char-repeatclj/s

(char-repeat n s)
source

concatvclj/s

(concatv & xs)

Concatenate xs and return the result as a vector.

Concatenate `xs` and return the result as a vector.
sourceraw docstring

get-terminal-widthclj/s

(get-terminal-width)
source

insert-atclj/s

(insert-at vc i elem)
source

join-linesclj/s

(join-lines coll)
(join-lines sep coll)
source

maybe->clj/s

(maybe-> x pred)

If (= (pred x) true), returns x, otherwise nil. Useful in a clojure.core/some-> threading form.

If `(= (pred x) true)`, returns x, otherwise nil.
Useful in a `clojure.core/some->` threading form.
sourceraw docstring

maybe->>clj/s

(maybe->> pred x)

If (= (pred x) true), returns x, otherwise nil. Useful in a clojure.core/some->> threading form.

If (= (pred x) true), returns x, otherwise nil.
Useful in a `clojure.core/some->>` threading form.
sourceraw docstring

partition-by-predclj/s

(partition-by-pred pred coll)
source

shortenedclj/s

(shortened v limit)

Stringifies a value and truncates the result with ellipsis so that it fits on one line.

Stringifies a value and truncates the result with ellipsis 
so that it fits on one line.
sourceraw docstring

sjrclj/s

(sjr n s)
source

string-of-1?clj/s

(string-of-1? x)
source

when->clj/s

(when-> x pred)

If (= (pred x) true), returns x, otherwise nil. Useful in a clojure.core/some-> threading form.

If `(= (pred x) true)`, returns x, otherwise nil.
Useful in a `clojure.core/some->` threading form.
sourceraw docstring

when->>clj/s

(when->> pred x)

If (= (pred x) true), returns x, otherwise nil. Useful in a clojure.core/some->> threading form.

If (= (pred x) true), returns x, otherwise nil.
Useful in a `clojure.core/some->>` threading form.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries